Learn R Programming

CEEMDANML (version 0.1.0)

carigas: CEEMDAN Decomposition-Based ARIMA-GARCH-SVR Hybrid Modeling

Description

CEEMDAN Decomposition-Based ARIMA-GARCH-SVR Hybrid Modeling

Usage

carigas(Y, ratio = 0.9, n_lag = 4)

Value

  • Train_fitted: Train fitted result

  • Test_predicted: Test predicted result

  • Accuracy: Accuracy

Arguments

Y

Univariate time series

ratio

Ratio of number of observations in training and testing sets

n_lag

Lag of the provided time series data

References

  • Garai, S., & Paul, R. K. (2023). Development of MCS based-ensemble models using CEEMDAN decomposition and machine intelligence. Intelligent Systems with Applications, 18, 200202

  • Garai, S., Paul, R. K., Rakshit, D., Yeasin, M., Paul, A. K., Roy, H. S., Barman, S. & Manjunatha, B. (2023). An MRA Based MLR Model for Forecasting Indian Annual Rainfall Using Large Scale Climate Indices. International Journal of Environment and Climate Change, 13(5), 137-150.

Examples

Run this code
Y <- rnorm(100, 100, 10)
result <- carigas(Y, ratio = 0.8, n_lag = 4)

Run the code above in your browser using DataLab